@@ -31,6 +31,7 @@ class PagePrivate;
 class PageTransition;
 class SourceReference;
 class TextSelection;
+class Tile;
 
 /**
  * @short Collector for all the data belonging to a page.
@@ -136,10 +137,10 @@ class OKULAR_EXPORT Page
         void setBoundingBox( const NormalizedRect& bbox );
 
         /**
-         * Returns whether the page has a pixmap of size @p width x @p height
-         * for the observer with given @p id.
+         * Returns whether the page of size @p width x @p height has a @p pixmap 
+         * in the region given by @rect for the observer with given @p id.
          */
-        bool hasPixmap( int id, int width = -1, int height = -1 ) const;
+        bool hasPixmap( int id, int width = -1, int height = -1, const NormalizedRect &rect = NormalizedRect() ) const;
 
         /**
          * Returns whether the page provides a text page (@ref TextPage).
@@ -223,6 +224,12 @@ class OKULAR_EXPORT Page
          */
         const ObjectRect * objectRect( ObjectRect::ObjectType type, double x, double y, double xScale, double yScale ) const;
 
+        /**
+         * Returns all object rects of the given @p type which are at point (@p x, @p y) at scale (@p xScale, @p yScale).
+         * @since 0.16 (KDE 4.10)
+         */
+        QLinkedList< const ObjectRect * > objectRects( ObjectRect::ObjectType type, double x, double y, double xScale, double yScale ) const;
+
         /**
          * Returns the object rect of the given @p type which is nearest to the point (@p x, @p y) at scale (@p xScale, @p yScale).
          *
@@ -253,9 +260,12 @@ class OKULAR_EXPORT Page
         QLinkedList< FormField * > formFields() const;
 
         /**
-         * Sets the @p pixmap for the observer with the given @p id.
+         * Sets the region described by @p rect with @p pixmap for the observer
+         * with the given @p id.
+         * If @p rect is not set (default) the @p pixmap is set to the entire
+         * page.
          */
-        void setPixmap( int id, QPixmap *pixmap );
+        void setPixmap( int id, QPixmap *pixmap, const NormalizedRect &rect = NormalizedRect() );
 
         /**
          * Sets the @p text page.
@@ -357,6 +367,23 @@ class OKULAR_EXPORT Page
          */
         void deleteAnnotations();
 
+        /**
+         * Returns whether pixmaps for the PAGEVIEW_ID observer are handled by a
+         * tile manager.
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        bool hasTilesManager() const;
+
+        /**
+         * Returns a list of all tiles intersecting with @p rect.
+         *
+         * The list contains only tiles with a pixmap
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        QList<Tile> tilesAt( const NormalizedRect &rect ) const;
+
     private:
         PagePrivate* const d;
         /// @cond PRIVATE
