@@ -400,7 +400,7 @@ static KAboutData createAboutData()
          "okular_poppler",
          "okular_poppler",
          ki18n( "PDF Backend" ),
-         "0.6.2",
+         "0.6.3",
          ki18n( "A PDF file renderer" ),
          KAboutData::License_GPL,
          ki18n( "© 2005-2008 Albert Astals Cid" )
@@ -1806,7 +1806,7 @@ void PDFGenerator::fillViewportFromSourceReference( Okular::DocumentViewport & v
     if (!ok) line = -1;
 
     // Use column == -1 for now.
-    if( synctex_display_query( synctex_scanner, name.toLatin1(), line, -1 ) > 0 )
+    if( synctex_display_query( synctex_scanner, QFile::encodeName(name), line, -1 ) > 0 )
     {
         synctex_node_t node;
         // For now use the first hit. Could possibly be made smarter
